@@ -96,7 +96,7 @@ typedef struct id3info {
   uint8_t tag_data_safe;
   uint32_t size;
   uint32_t size_remain;
-  uint32_t offset; // For non-MP3, offset into file where tag begins
+  off_t offset; // For non-MP3, offset into file where tag begins
 } id3info;
 
 typedef struct id3_compat {
@@ -117,7 +117,7 @@ extern struct id3_frametype const id3_frametype_experimental;
 extern struct id3_frametype const id3_frametype_unknown;
 extern struct id3_frametype const id3_frametype_obsolete;
 
-int parse_id3(PerlIO *infile, char *file, HV *info, HV *tags, uint32_t seek, off_t file_size);
+int parse_id3(PerlIO *infile, char *file, HV *info, HV *tags, off_t seek, off_t file_size);
 int _id3_parse_v1(id3info *id3);
 int _id3_parse_v2(id3info *id3);
 int _id3_parse_v2_frame(id3info *id3);
