@@ -129,30 +129,30 @@ _mpc_read_header_sv8(mpc_streaminfo *si)
   unsigned char blocktype[2];
   unsigned char *bptr = buffer_ptr(si->buf);
   uint64_t size;
-  
+
   while ( memcmp(bptr, "AP", 2) != 0 ) { // scan all blocks until audio
     memcpy(blocktype, bptr, 2);
     buffer_consume(si->buf, 2);
-    
+
     _mpc_bits_get_size(si->buf, &size);
     size -= 3;
-    
+
     DEBUG_TRACE("%c%c block, size %llu\n", blocktype[0], blocktype[1], size);
-    
+
     if ( !_check_buf(si->infile, si->buf, size, MPC_BLOCK_SIZE) ) {
       return -1;
     }
-    
+
     if (memcmp(blocktype, "SH", 2) == 0) {
       // Skip CRC
       buffer_consume(si->buf, 4);
-      
+
       si->stream_version = buffer_get_char(si->buf);
       _mpc_bits_get_size(si->buf, &si->pcm_samples);
       _mpc_bits_get_size(si->buf, &si->beg_silence);
-      
+
       si->is_true_gapless = 1;
-      
+
       bptr = buffer_ptr(si->buf);
       si->sample_freq = samplefreqs[ (bptr[0] & 0xE0) >> 5 ];
       si->max_band = (bptr[0] & 0x1F) + 1;
@@ -172,29 +172,29 @@ _mpc_read_header_sv8(mpc_streaminfo *si)
         si->peak_title = buffer_get_short(si->buf);
         si->gain_album = buffer_get_short(si->buf);
         si->peak_album = buffer_get_short(si->buf);
-      }      
+      }
     }
     else if (memcmp(blocktype, "EI", 2) == 0) {
       bptr = buffer_ptr(si->buf);
-      
+
       si->fprofile = ((bptr[0] & 0xFE) >> 1) / 8.;
       si->profile_name = _mpc_profile_string((uint32_t)si->fprofile);
       buffer_consume(si->buf, 1);
-      
+
       si->encoder_version = buffer_get_char(si->buf) << 24; // major
       si->encoder_version |= buffer_get_char(si->buf) << 16; // minor
       si->encoder_version |= buffer_get_char(si->buf) << 8; // build
       DEBUG_TRACE("ver: %d\n", si->encoder_version);
-      
+
       _mpc_get_encoder_string(si);
     }
     else {
       break;
     }
-    
+
     bptr = buffer_ptr(si->buf);
   }
-  
+
   return 0;
 }
 
@@ -210,12 +210,12 @@ _mpc_read_header_sv7(mpc_streaminfo *si)
 
   si->bitrate            = 0;
   si->frames             = buffer_get_int_le(si->buf);
-  
+
   bptr = buffer_ptr(si->buf);
   si->is                 = (bptr[3] >> 7) & 0x1;
   si->ms                 = (bptr[3] >> 6) & 0x1;
   si->max_band           = bptr[3] & 0x3F;
-   
+
   si->block_size         = 1;
   si->profile            = (bptr[2] >> 4) & 0xF;
   si->profile_name       = _mpc_profile_string(si->profile);
@@ -223,37 +223,37 @@ _mpc_read_header_sv7(mpc_streaminfo *si)
   si->sample_freq        = samplefreqs[bptr[2] & 0x3];
   // skip MaxLevel
   buffer_consume(si->buf, 4);
-  
+
   si->peak_title         = buffer_get_short_le(si->buf);
   si->gain_title         = buffer_get_short_le(si->buf);
-  
+
   si->peak_album         = buffer_get_short_le(si->buf);
   si->gain_album         = buffer_get_short_le(si->buf);
-  
+
   // convert gain info
   if (si->gain_title != 0) {
     int tmp = (int)((MPC_OLD_GAIN_REF - (int16_t)si->gain_title / 100.) * 256. + .5);
     if (tmp >= (1 << 16) || tmp < 0) tmp = 0;
     si->gain_title = (int16_t)tmp;
   }
-  
+
   if (si->gain_album != 0) {
     int tmp = (int)((MPC_OLD_GAIN_REF - (int16_t)si->gain_album / 100.) * 256. + .5);
     if (tmp >= (1 << 16) || tmp < 0) tmp = 0;
     si->gain_album = (int16_t)tmp;
   }
-  
+
   if (si->peak_title != 0)
     si->peak_title = (uint16_t) (log10(si->peak_title) * 20 * 256 + .5);
 
   if (si->peak_album != 0)
     si->peak_album = (uint16_t) (log10(si->peak_album) * 20 * 256 + .5);
-  
+
   bptr = buffer_ptr(si->buf);
   si->is_true_gapless    = (bptr[3] >> 7) & 0x1;
   si->last_frame_samples = ((bptr[3] >> 1) & 0x7F) | ((bptr[2] >> 4) & 0xF);  // true gapless: valid samples for last frame
   buffer_consume(si->buf, 4);
-  
+
   bptr = buffer_ptr(si->buf);
   si->encoder_version    = bptr[3];
   si->channels           = 2;
@@ -274,7 +274,7 @@ get_mpcfileinfo(PerlIO *infile, char *file, HV *info)
 
   Newz(0, si, sizeof(mpc_streaminfo), mpc_streaminfo);
   buffer_init(&buf, MPC_BLOCK_SIZE);
-  
+
   si->buf    = &buf;
   si->infile = infile;
 
@@ -289,7 +289,7 @@ get_mpcfileinfo(PerlIO *infile, char *file, HV *info)
     PerlIO_printf(PerlIO_stderr(), "Musepack: [Couldn't seek to offset %d]: %s\n", si->header_position, file);
     goto out;
   }
-  
+
   if ( !_check_buf(infile, &buf, 128, MPC_BLOCK_SIZE) ) {
     goto out;
   }
@@ -300,9 +300,9 @@ get_mpcfileinfo(PerlIO *infile, char *file, HV *info)
   }
 
   si->tag_offset = PerlIO_tell(infile);
-  
+
   si->total_file_length = _file_size(infile);
-  
+
   bptr = buffer_ptr(&buf);
 
   if (memcmp(bptr, "MP+", 3) == 0) {
@@ -317,7 +317,7 @@ get_mpcfileinfo(PerlIO *infile, char *file, HV *info)
   }
   else if (memcmp(bptr, "MPCK", 4) == 0) {
     buffer_consume(&buf, 4);
-    
+
     DEBUG_TRACE("parsing MPC SV8 header\n");
     ret = _mpc_read_header_sv8(si);
   }
@@ -338,17 +338,15 @@ get_mpcfileinfo(PerlIO *infile, char *file, HV *info)
     my_hv_store(info, "channels", newSViv(si->channels));
     my_hv_store(info, "song_length_ms", newSVuv(total_seconds * 1000));
     my_hv_store(info, "bitrate", newSVuv(8 * (double)(si->total_file_length - si->tag_offset) / total_seconds));
-    
+
     my_hv_store(info, "audio_offset", newSVuv(si->tag_offset));
     my_hv_store(info, "audio_size", newSVuv(si->total_file_length - si->tag_offset));
     my_hv_store(info, "file_size", newSVuv(si->total_file_length));
-    
-    if (si->encoder)
-      my_hv_store(info, "encoder", newSVpv(si->encoder, 0));
-    
+    my_hv_store(info, "encoder", newSVpv(si->encoder, 0));
+
     if (si->profile_name)
       my_hv_store(info, "profile", newSVpv(si->profile_name, 0));
-    
+
     my_hv_store(info, "gapless", newSViv(si->is_true_gapless));
     my_hv_store(info, "track_gain", newSVpvf("%2.2f dB", si->gain_title == 0 ? 0 : MPC_OLD_GAIN_REF - si->gain_title / 256.0));
     my_hv_store(info, "album_gain", newSVpvf("%2.2f dB", si->gain_album == 0 ? 0 : MPC_OLD_GAIN_REF - si->gain_album / 256.0));
